==> react-components-library-0.0.27.tgz: package/src/ProgressBar/index.tsx <==
import React from "react";
import { Color, ColorPropType } from "../types";
import PropTypes from "prop-types";
import styling from "@devcake/styling";
import { useStyle } from "../Scope";

styling.setDefault("components.progress.container", "relative h-4 bg-gray-100 rounded-full");
styling.setDefault("components.progress.selected", "absolute h-4 inline-block rounded-full transition-all duration-500 ease-linear");
styling.setDefault("components.progress.tracker", "absolute right-0");

export type ProgressBarProps = {
  color?: Color;
  current: number;
  max?: number;
  min?: number;
  onClick?: React.MouseEventHandler;
  onMouseDown?: React.MouseEventHandler;
  onMouseEnter?: React.MouseEventHandler;
  onMouseLeave?: React.MouseEventHandler;
  onMouseMove?: React.MouseEventHandler;
  onMouseUp?: React.MouseEventHandler;
  tracker?: React.ReactNode;
}

export const ProgressBar = React.forwardRef<HTMLDivElement, ProgressBarProps>(({
                                                                                 color,
                                                                                 current,
                                                                                 min,
                                                                                 max,
                                                                                 onClick,
                                                                                 onMouseDown,
                                                                                 onMouseEnter,
                                                                                 onMouseLeave,
                                                                                 onMouseMove,
                                                                                 onMouseUp,
                                                                                 tracker
                                                                               }, ref) => {
  let width = (current - min) / (max - min);
  if (width > 1) width = 1;
  else if (width < 0) width = 0;

  const [containerStyle, selectedStyle, trackerStyle] = useStyle(["container", "selected", "tracker"], "components.progress");

  return (
    <div
      className={containerStyle}
      onClick={onClick}
      onMouseDown={onMouseDown}
      onMouseEnter={onMouseEnter}
      onMouseLeave={onMouseLeave}
      onMouseMove={onMouseMove}
      onMouseUp={onMouseUp}
      ref={ref}
    >
      <div
        className={`bg-${color}-600 ${selectedStyle}`}
        style={{ width: `${(width * 100).toFixed(1)}%` }}>
        {tracker && (
          <div className={trackerStyle}>
            {tracker}
          </div>
        )}
      </div>
    </div>
  );
});
ProgressBar.propTypes = {
  color: ColorPropType,
  current: PropTypes.number.isRequired,
  max: PropTypes.number,
  min: PropTypes.number,
  tracker: PropTypes.node
};
ProgressBar.defaultProps = {
  color: "blue",
  min: 0,
  max: 1
};

==> react-components-library-0.0.35.tgz: package/src/ProgressBar/index.tsx <==
import React from "react";
import { Color, ColorPropType } from "../types";
import PropTypes from "prop-types";
import styling from "@devcake/styling";
import { useStyle } from "../Scope";
import colors from "./colors";

styling.setDefault("components.progress.container", "relative h-4 bg-gray-100 rounded-full");
styling.setDefault("components.progress.selected", "absolute h-4 inline-block rounded-full transition-all duration-500 ease-linear");
styling.setDefault("components.progress.tracker", "absolute right-0");

export type ProgressBarProps = {
  color?: Color;
  current: number;
  max?: number;
  min?: number;
  onClick?: React.MouseEventHandler;
  onMouseDown?: React.MouseEventHandler;
  onMouseEnter?: React.MouseEventHandler;
  onMouseLeave?: React.MouseEventHandler;
  onMouseMove?: React.MouseEventHandler;
  onMouseUp?: React.MouseEventHandler;
  tracker?: React.ReactNode;
}

export const ProgressBar = React.forwardRef<HTMLDivElement, ProgressBarProps>(({
                                                                                 color,
                                                                                 current,
                                                                                 min,
                                                                                 max,
                                                                                 onClick,
                                                                                 onMouseDown,
                                                                                 onMouseEnter,
                                                                                 onMouseLeave,
                                                                                 onMouseMove,
                                                                                 onMouseUp,
                                                                                 tracker
                                                                               }, ref) => {
  let width = (current - min) / (max - min);
  if (width > 1) width = 1;
  else if (width < 0) width = 0;

  const [containerStyle, selectedStyle, trackerStyle] = useStyle(["container", "selected", "tracker"], "components.progress");

  return (
    <div
      className={containerStyle}
      onClick={onClick}
      onMouseDown={onMouseDown}
      onMouseEnter={onMouseEnter}
      onMouseLeave={onMouseLeave}
      onMouseMove={onMouseMove}
      onMouseUp={onMouseUp}
      ref={ref}
    >
      <div
        className={`${colors[color]} ${selectedStyle}`}
        style={{ width: `${(width * 100).toFixed(1)}%` }}>
        {tracker && (
          <div className={trackerStyle}>
            {tracker}
          </div>
        )}
      </div>
    </div>
  );
});
ProgressBar.propTypes = {
  color: ColorPropType,
  current: PropTypes.number.isRequired,
  max: PropTypes.number,
  min: PropTypes.number,
  tracker: PropTypes.node
};
ProgressBar.defaultProps = {
  color: "blue",
  min: 0,
  max: 1
};
